SavedGame class
Properties
-
deviceName
↔ String
-
The device that saved the game.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
modificationDate
↔ int
-
The modification date, this will be also the creation date once you create the
saved game for the first time. The date is in milliseconds.
getter/setter pair
-
name
↔ String
-
The saved game name.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited